Attribute Macros
- provider
- This proc macro is used internally by the
construct_provider!macro and should not be used directly by users. This macro generates the necessary code for creating a provider, including the provider struct, configuration, resources link, and state management. It also handles the provider’s lifecycle, such as the initialization and the drop operation. - resource
- This proc macro is used to define a resource.